require("mod-gui")


function get_info()
	local time = 0

	if remote.interfaces.MoWeather then
		time = remote.call("MoWeather","getdaytime") *24 +12
	else
		time = game.surfaces[1].daytime *24 +12
	end
	if time >= 24 then
		time = time -24
	end

	local min = math.floor((time % 1) * 60)
	local hour = math.floor(time)
	local hour12 = hour % 12
	if hour12 == 0 then hour12 = 12 end

	local text24 = string.format("%02d:%02d", hour, min)
	local text12 = string.format("%d:%02d", hour12, min)
	if  hour / 12 < 1 then
		text12 = text12 .. " AM"
	else
		text12 = text12 .. " PM"
	end

	local played = game.ticks_played
	local played_sec = math.floor((played % 3600)/60)
	local played_min = math.floor((played % 216000)/3600)
	local played_hour = math.floor(played/216000)

	return
	{
		time =
		{
			min = min,
			hour = hour,
			hour12 = hour12,
			text12 = text12,
			text24 = text24
		},
		played =
		{
			sec = played_sec,
			min = played_min,
			hour = played_hour
		},
		time_played = string.format(": %d:%02d:%02d", played_hour, played_min, played_sec),
		evolution_factor = string.format(": %d%%", math.floor(game.forces["enemy"].evolution_factor * 100)),
		speed = string.format(": %d%%", math.floor(game.speed * 100)),
	}
end


script.on_event(defines.events.on_tick, function(event)
	local info = get_info()

	if global.min_previous ~= info.time.min then
		for i, player in pairs(game.connected_players) do
			if player.gui.top.clockGUI == nil then player.gui.top.add{type="button", name="clockGUI", style="jclock_button"} end
			
			local shortvalue = settings.get_player_settings(player)["Jclock-shortvalue"].value
			local minshort = (math.floor((info.time.min / shortvalue) + .5)) * shortvalue
			local hour = info.time.hour
			local hour12 = info.time.hour12
			
			if minshort >= 60 then
				minshort = 0
				hour = hour + 1
				hour12 = hour12 + 1
			end
			if hour >= 24 then hour = hour - 24 end
			if hour12 > 12 then hour12 = hour12 - 12 end
			local text24short = string.format("%02d:%02d", hour, minshort)
			local text12short = string.format("%d:%02d", hour12, minshort)
			if  hour / 12 < 1 then
				text12short = text12short .. " AM"
			else
				text12short = text12short .. " PM"
			end
			
			local timetextshort = text12short
			if settings.get_player_settings(player)["Jclock-24hour"].value == true then
				timetextshort = text24short
			end
						
			local timetext = info.time.text12
			if settings.get_player_settings(player)["Jclock-24hour"].value == true then
				timetext = info.time.text24
			end
			player.gui.top.clockGUI.caption = timetextshort
			if global.player[player.index].gui then
				global.player[player.index].gui.time.caption = {"gui.clock-time", ": " .. timetext}
			end
		end
	end

	if global.sec_previous ~= played_sec then
		for i, player in pairs(game.connected_players) do
			if global.player[player.index].gui then
				global.player[player.index].gui.time_played.caption = {"gui.clock-time-played", info.time_played }
				global.player[player.index].gui.evolution_factor.caption = {"gui.clock-evolution-factor", info.evolution_factor }
				global.player[player.index].gui.speed.caption = {"gui.clock-game-speed", info.speed }
			end
		end
	end

	global.min_previous = info.time.min
	global.sec_previous = info.played.sec
end)


function setup(event)
	if not global.player then
		global.player = {}
	end
	for i, player in pairs(game.players) do
		if player.gui.top.clockGUI then
			player.gui.top.clockGUI.visible = true
		end
		if not global.player[player.index] then
			global.player[player.index] = {
				options = false,
				gui = nil
			}
		end
	end
end

script.on_init(function(event)
	setup(event)
end)
script.on_configuration_changed(function(event)
	setup(event)
end)
script.on_event(defines.events.on_player_created, function(event)
	local player = game.players[event.player_index]
	
	if not global.player then
		setup(event)
	end
	if player.gui.top.clockGUI then
		player.gui.top.clockGUI.visible = true
	end
	if not global.player[event.player_index] then
		global.player[event.player_index] = {
			options = false,
			gui = nil
		}
	end
end)


script.on_event(defines.events.on_gui_click, function(event)
	local player = game.players[event.player_index]

	if event.element.valid then
		if event.element.name == "clockGUI" then
			draw_gui(event.player_index)
		end
	end
end)

function draw_gui(player_index)
	local player = game.players[player_index]

	if mod_gui.get_frame_flow(player).clock_gui then
		mod_gui.get_frame_flow(player).clock_gui.destroy()
		global.player[player_index].gui = nil
	else
		local gui = mod_gui.get_frame_flow(player).add({type = "frame", name = "clock_gui", direction = "vertical", caption = {"gui.clock-gui"}})
		global.player[player_index].gui = gui

		local info = get_info()
		local timetext = info.time.text12
		if settings.get_player_settings(player)["Jclock-24hour"].value == true then
			timetext = info.time.text24
		end
		gui.add({type = "label", name = "time", caption = {"gui.clock-time", ": " .. timetext }})
		gui.add({type = "label", name = "time_played", caption = {"gui.clock-time-played", info.time_played }})
		gui.add({type = "label", name = "evolution_factor", caption = {"gui.clock-evolution-factor", info.evolution_factor }})
		gui.add({type = "label", name = "speed", caption = {"gui.clock-game-speed", info.speed }})
	end
end

